@@ -1,13 +1,14 @@
-#!/usr/bin/perl
+#!/usr/bin/env perl
 BEGIN { $| = 1; }
 use warnings;
 use strict;
 use File::Spec;
 use Getopt::Long;
-use Digest::SHA1 qw(sha1_hex);
+use Digest::SHA qw(sha1_hex);
+Getopt::Long::Configure('no_ignore_case');
 
 # This is updated by the update-revision.pl script.
-my $revision = 10800;
+my $revision = 12312;
 
 # Generate list with:
 # vislcg3 --help 2>&1 | perl -wpne 'if (/^ / && /-(\w), --([-\w]+)/) {print "$2|$1=s\n"} elsif (/^ / && /--([-\w]+)/) {print "$1=s\n"} s/^.*$//s;' | perl -wpne 's/^/"/; s/$/",/;'
@@ -42,7 +43,7 @@ GetOptions (\%h,
 "no-before-sections",
 "no-sections",
 "no-after-sections",
-"trace|t",
+"trace|t:s",
 "trace-name-only",
 "trace-no-removed",
 "trace-encl",
@@ -65,10 +66,13 @@ GetOptions (\%h,
 "dep-no-crossing",
 "no-magic-readings",
 "no-pass-origin|o",
+"split-mappings",
 "show-end-tags|e",
 "show-unused-sets",
+"show-tags",
 "show-tag-hashes",
-"show-set-hashes"
+"show-set-hashes",
+"dump-ast"
 );
 
 if (defined $h{'grammar-bin'}) {
